%%Post processing analysis with moving interval on LN-transformed area data to calculate mu-Monod
%%

clear all

% Get path to the current directory of this script
resultPath = matlab.desktop.editor.getActiveFilename;
fprintf('%s\n', resultPath);
% Find all indices of the '/'
slashIndices = find(resultPath == '/');
% Find the index of the 3rd '/' from the end
thirdSlashFromEndIndex = slashIndices(end-2);
% Remove the part after the 3rd '/' from the end
Currentdir = resultPath(1:thirdSlashFromEndIndex);
fprintf('%s\n', Currentdir);

% path to main folder with images
Main = strcat(Currentdir,'raw_data/microplate_reader/microplate_reader_PPU_PVE/succinate 10mM/')

annotation=readtable(strcat(Main, 'OD_GFP_mCherry_curves.xlsx'),'Sheet','R1_OD600','Range','B1:Y1','ReadVariableNames',false);
annotation=table2array(annotation);

A=readmatrix(strcat(Main, 'OD_GFP_mCherry_curves.xlsx'),'Sheet','R1_OD600'); %first column is time

A(:,1)=[];

%%extract mu and rsq with a gliding scale - here 10 points

w1=20; %for the first 10 hours, is 20 points
t=[30:30:w1*30]/60; %time scale in hours for the length of the table

int=5; %number of points for the floating interval

for k=1:size(A,2)
    for z=1:length(t)-int
        [r(z), m(z), b(z)]=regression(t(z:z+int),log(A(z:z+int,k))');
        %m=slope, b=intercept
    end
    best_r=find(r>0.97); %find the intervals where the rsq is above 0.97
    best_m=mean(m(best_r)); %take the mean mu for those intervals
    best_r_m=mean(r(best_r)); %take the mean rsq for those intervals

    pos.mu(k)=best_m; %to collect all data
    pos.rsq(k)=best_r_m;
    pos.net_area(k)=A(end,k)-A(1,k);

end %end loop



PPU=({'B2','C2','D2','E2','F2','G2'});
idx=find(matches(annotation,PPU));
PPU_mu=pos.mu(idx);
PVE=({'B3','C3','D3','E3','F3','G3'});
idxv=find(matches(annotation,PVE));
PVE_mu=pos.mu(idxv);
mix=({'B4','C4','D4','E4','F4','G4'});
idxm=find(matches(annotation,mix));
PPU_PVE_mu=pos.mu(idxm);


%%plot ln-transformed OD per well over time (if needed)

close all
T=[30:30:size(A,1)*30]/60; %time scale in hours for the length of the table
%plot(T,log(A)); %for the whole table
PVE_sub=A(:,idxv); %subset of e.g., only PVE growth data
plot(T,log(PVE_sub));


%% fit log and lag data

addpath(strcat(Currentdir,'/additional_matlab_function_scripts/'))


for k=1:size(A,2)


    Time_step=T;
    Evol_mass=A(:,k);
    aa=min(find(Evol_mass>0.08)); %value in the blanc
    if ~isempty(aa)

        AA=Evol_mass(aa);
        Evol_mass(Evol_mass<AA)=0.08;
        lag_time=0;

        x0 = [1, max(Evol_mass), Evol_mass(1), lag_time];
        opts_1 = odeset('RelTol',1e-9,'AbsTol',1e-10);
        fun_Logistic = @(x, Time_step) x(2)./(1 + (x(2) - x(3))/x(3).*exp(-x(1)*Time_step));

        [pars, ~] = fminsearch(@(x) -logLikelihood(Evol_mass, 1e02, Time_step, 0, x(1), x(4), x(2), opts_1),...
            x0,...%Initial guess
            optimset('MaxFunEvals', 20000));

        sol = ode45(@(t,x) dfun(t, x, Evol_mass(1), 0, pars(1), pars(4), pars(2)), [0 max(Time_step)], Evol_mass(1), opts_1);
        x_est = deval(sol, Time_step);

        time_init(k)=pars(4);
        mu_log(k)=pars(1);


        pos.time_init=time_init;
        pos.mu_log=mu_log;

    else
        time_init(k)=NaN;
        mu_log(k)=NaN;

        pos.time_init=time_init; %fitted lag time (h)
        pos.mu_log=mu_log; %fitted logaritmic growth rate - to compare to mu_monod; multiply by log(2)


    end
end %end fitting loop

%%results
PPU_mu=[0.315549012691898	0.324087119252211	0.321702758505353	0.324808081716008	0.319727063653994	0.330398127053888]
% PPU_PVE_mu=0.295684755314621	0.310303045794136	0.307419164121464	0.302248570039690	0.307829808585011	0.292856493999737
PVE_mu=[0.161692108912126	0.183403958460501	0.183025114215352	0.209694977862557	0.221476950093507	0.204326807270468]

%%time to first doubling is fitted lag time plus the inverse of the mu_log, corrected for ln(2)

lag=[pos.time_init(:)];
mu_log=[pos.mu_log(:)];
lag(lag<-0.01)=0.01;

time_doubling=lag+1./mu_log./log(2);
time_doubling=time_doubling';

PPU_time_init=pos.time_init(idx);
%%
%0.000497905168502623	2.69090382555002	0.000839616021425020	0.000567115800749111	0.000804068320353238	0.000402679712030455
%%
PPU_mu_log=pos.mu_log(idx);
%%
%0.433854706040618	0.778076830636413	0.470008916881613	0.477726039129027	0.492704624956537	0.492298769384327
%%
PVE_time_init=pos.time_init(idxv);
%%
%0.00116387444431389	-0.00143791761263289	-0.00127050911531513	-0.00227097930568781	-0.000597116037272691	-3.15829690048035e-05
%%
PVE_mu_log=pos.mu_log(idxv);
%%
%0.209422677803285	0.247436850170933	0.223883932018440	0.246775751859649	0.258951035385042	0.244314407079210
%%
PPU_PVE_time_init=pos.time_init(idxm);
%%
%0.00130026968053403	0.000421881252621409	0.000269448078059896	0.000219726279970658	0.000296426131460221	3.71724385811005
%%
PPU_td=time_doubling(idx);
%% in h
PPU_td=[3.32579326511764	4.54508452350107	3.07034529787289	3.02048841529540	2.92891752172305	2.93093009641309]
%%
PVE_td=time_doubling(idxv);
%%
PVE_td=[6.89007894334680	5.82912062648590	6.44267134898167	5.84390730205755	5.57070727648534	5.90504400441223]
%%
PPU_PVE_td=time_doubling(idxm);
%%
%3.43232036701645	3.17638475438813	3.31881220026094	3.26967595893069	3.21304202018966	5.10104847029159


%%repeat for the GFP channel

clear

% Get path to the current directory of this script
resultPath = matlab.desktop.editor.getActiveFilename;
fprintf('%s\n', resultPath);
% Find all indices of the '/'
slashIndices = find(resultPath == '/');
% Find the index of the 3rd '/' from the end
thirdSlashFromEndIndex = slashIndices(end-2);
% Remove the part after the 3rd '/' from the end
Currentdir = resultPath(1:thirdSlashFromEndIndex);
fprintf('%s\n', Currentdir);

% path to main folder with images
Main = strcat(Currentdir,'raw_data/microplate_reader/microplate_reader_PPU_PVE/succinate 10mM/')


annotation=readtable(strcat(Main, 'OD_GFP_mCherry_curves.xlsx'),'Sheet','R1_GFP','Range','B1:Y1','ReadVariableNames',false);
annotation=table2array(annotation);

A=readmatrix(strcat(Main, 'OD_GFP_mCherry_curves.xlsx'),'Sheet','R1_GFP'); %first column is time

A(:,1)=[];

%%extract mu and rsq with a gliding scale - here 10 points

w1=20; %for the first 10 hours, is 20 points
t=[30:30:w1*30]/60; %time scale in hours for the length of the table

int=5; %number of points for the floating interval

for k=1:size(A,2)
    for z=1:length(t)-int
        [r(z), m(z), b(z)]=regression(t(z:z+int),log(A(z:z+int,k))');
        %m=slope, b=intercept
    end
    best_r=find(r>0.97); %find the intervals where the rsq is above 0.99
    best_m=mean(m(best_r)); %take the mean mu for those intervals
    best_r_m=mean(r(best_r)); %take the mean rsq for those intervals

    pos.mu(k)=best_m; %to collect all data
    pos.rsq(k)=best_r_m;
    pos.net_area(k)=A(end,k)-A(1,k);

end %end loop



PPU=({'B2','C2','D2','E2','F2','G2'});
idx=find(matches(annotation,PPU));
PPU_mu=pos.mu(idx);
PVE=({'B3','C3','D3','E3','F3','G3'});
idxv=find(matches(annotation,PVE));
PVE_mu=pos.mu(idxv);
mix=({'B4','C4','D4','E4','F4','G4'});
idxm=find(matches(annotation,mix));
PPU_PVE_mu=pos.mu(idxm);



%%plot ln-transformed OD per well over time (if needed)

close all
T=[30:30:size(A,1)*30]/60; %time scale in hours for the length of the table
plot(T,log(A));


%% fit log and lag data

addpath(strcat(Currentdir,'/additional_matlab_function_scripts/'))

for k=1:size(A,2)


    Time_step=T;
    Evol_mass=A(:,k);
    aa=min(find(Evol_mass>100)); %value in the blanc
    if ~isempty(aa)

        AA=Evol_mass(aa);
        Evol_mass(Evol_mass<AA)=100;
        lag_time=0;

        x0 = [1, max(Evol_mass), Evol_mass(1), lag_time];
        opts_1 = odeset('RelTol',1e-9,'AbsTol',1e-10);
        fun_Logistic = @(x, Time_step) x(2)./(1 + (x(2) - x(3))/x(3).*exp(-x(1)*Time_step));

        [pars, ~] = fminsearch(@(x) -logLikelihood(Evol_mass, 1e02, Time_step, 0, x(1), x(4), x(2), opts_1),...
            x0,...%Initial guess
            optimset('MaxFunEvals', 20000));

        sol = ode45(@(t,x) dfun(t, x, Evol_mass(1), 0, pars(1), pars(4), pars(2)), [0 max(Time_step)], Evol_mass(1), opts_1);
        x_est = deval(sol, Time_step);

        time_init(k)=pars(4);
        mu_log(k)=pars(1);


        pos.time_init=time_init;
        pos.mu_log=mu_log;

    else
        time_init(k)=NaN;
        mu_log(k)=NaN;

        pos.time_init=time_init; %fitted lag time (h)
        pos.mu_log=mu_log; %fitted logaritmic growth rate


    end
end %end fitting loop

%%results
PPU_mu=[0.538373940238686	0.529620058098032	0.539818761666151	0.559104085095022	0.548634884811794	0.575585170752410];
PPU_PVE_mu=[0.523927285745241	0.546356676294748	0.516962778105204	0.498883767241037	0.508906752753092	0.511529480375226]
% PVE_mu=0.145919473834457	0.126826273736106	0.100412477460028	0.122930562873902	0.117439366179614	0.143508370669603

lag=[pos.time_init(:)];
mu_log=[pos.mu_log(:)];
lag(lag<-0.01)=0.01;

time_doubling=lag+1./mu_log./log(2);
time_doubling=time_doubling';

PPU_time_init=pos.time_init(idx);
%%
% 1.47097922313238	2.46933481657823	2.56843507880556	0.000174012212778579	2.32043857330392	2.32659899599586
%%
PPU_mu_log=pos.mu_log(idx);
%%
% 0.874909683150776	1.07376897195341	1.16069035372783	0.748486731003618	1.12255814387536	1.17742873634880
%%
PVE_time_init=pos.time_init(idxv);
%%
% -0.00256290748284740	0.000912760099356608	0.00865314059639277	-0.00460851310240087	6.80760582630684	0.00227935234085477
%%
PVE_mu_log=pos.mu_log(idxv);
%%
% 0.113933408090474	0.122901578230716	0.119609721042862	0.117061948841535	0.384798307325680	0.119215669493864
%%
PPU_PVE_time_init=pos.time_init(idxm);
%%
% 2.55579408831900	-1.38121330132727e-05	3.08171399781636	0.00134008658561755	3.13421347707751	3.63111242634138
%%
PPU_td=time_doubling(idx);
%% in h
PPU_td=[3.11994376047005	3.81291530602411	3.81139797261734	1.92765646598254	3.60562370937929	3.55189187050370];
%%
PVE_td=time_doubling(idxv);
%%
% 12.6600534845707	11.7395337091377	12.0703403371745	12.3195929474587	10.5568298052676	12.1038348526706
%%
PPU_PVE_td=time_doubling(idxm);
%%
PPU_PVE_td=[3.80010641330581	1.95606165527255	4.18688220155994	1.98599017379505	4.19918694676970	4.60962338884674];

%%repeat for the mCherry channel

clear

% Get path to the current directory of this script
resultPath = matlab.desktop.editor.getActiveFilename;
fprintf('%s\n', resultPath);
% Find all indices of the '/'
slashIndices = find(resultPath == '/');
% Find the index of the 3rd '/' from the end
thirdSlashFromEndIndex = slashIndices(end-2);
% Remove the part after the 3rd '/' from the end
Currentdir = resultPath(1:thirdSlashFromEndIndex);
fprintf('%s\n', Currentdir);

% path to main folder with images
Main = strcat(Currentdir,'raw_data/microplate_reader/microplate_reader_PPU_PVE/succinate 10mM/')

annotation=readtable(strcat(Main, 'OD_GFP_mCherry_curves.xlsx'),'Sheet','R1_GFP','Range','B1:Y1','ReadVariableNames',false);
annotation=table2array(annotation);

A=readmatrix(strcat(Main, 'OD_GFP_mCherry_curves.xlsx'),'Sheet','R1_mCherry'); %first column is time

A(:,1)=[];

%%extract mu and rsq with a gliding scale - here 10 points

w1=20; %for the first 10 hours, is 20 points
t=[30:30:w1*30]/60; %time scale in hours for the length of the table

int=5; %number of points for the floating interval

for k=1:size(A,2)
    for z=1:length(t)-int
        [r(z), m(z), b(z)]=regression(t(z:z+int),log(A(z:z+int,k))');
        %m=slope, b=intercept
    end
    best_r=find(r>0.97); %find the intervals where the rsq is above 0.99
    best_m=mean(m(best_r)); %take the mean mu for those intervals
    best_r_m=mean(r(best_r)); %take the mean rsq for those intervals

    pos.mu(k)=best_m; %to collect all data
    pos.rsq(k)=best_r_m;
    pos.net_area(k)=A(end,k)-A(1,k);

end %end loop


PPU=({'B2','C2','D2','E2','F2','G2'});
idx=find(matches(annotation,PPU));
PPU_mu=pos.mu(idx);
PVE=({'B3','C3','D3','E3','F3','G3'});
idxv=find(matches(annotation,PVE));
PVE_mu=pos.mu(idxv);
mix=({'B4','C4','D4','E4','F4','G4'});
idxm=find(matches(annotation,mix));
PPU_PVE_mu=pos.mu(idxm);



%%plot ln-transformed OD per well over time (if needed)

close all
T=[30:30:size(A,1)*30]/60; %time scale in hours for the length of the table
plot(T,log(A));


%% fit log and lag data

addpath(strcat(Currentdir,'/additional_matlab_function_scripts/'))

for k=1:size(A,2)


    Time_step=T;
    Evol_mass=A(:,k);
    aa=min(find(Evol_mass>100)); %value in the blanc
    if ~isempty(aa)

        AA=Evol_mass(aa);
        Evol_mass(Evol_mass<AA)=100;
        lag_time=0;

        x0 = [1, max(Evol_mass), Evol_mass(1), lag_time];
        opts_1 = odeset('RelTol',1e-9,'AbsTol',1e-10);
        fun_Logistic = @(x, Time_step) x(2)./(1 + (x(2) - x(3))/x(3).*exp(-x(1)*Time_step));

        [pars, ~] = fminsearch(@(x) -logLikelihood(Evol_mass, 1e02, Time_step, 0, x(1), x(4), x(2), opts_1),...
            x0,...%Initial guess
            optimset('MaxFunEvals', 20000));

        sol = ode45(@(t,x) dfun(t, x, Evol_mass(1), 0, pars(1), pars(4), pars(2)), [0 max(Time_step)], Evol_mass(1), opts_1);
        x_est = deval(sol, Time_step);

        time_init(k)=pars(4);
        mu_log(k)=pars(1);


        pos.time_init=time_init;
        pos.mu_log=mu_log;

    else
        time_init(k)=NaN;
        mu_log(k)=NaN;

        pos.time_init=time_init; %fitted lag time (h)
        pos.mu_log=mu_log; %fitted logaritmic growth rate


    end
end %end fitting loop

%%results

 % PPU_mu= NaN	NaN	NaN	NaN	NaN	NaN
PVE_PPU_mu=[0.385949726375610	0.407045175844202	0.377631278652892	0.413069106237179	0.452998973378401	0.423862188401780];
PVE_mu=[0.324931625014460	0.357617334798899	0.354335990004726	0.340581904974859	0.343411943416151	0.349222433137798];
lag=[pos.time_init(:)];
mu_log=[pos.mu_log(:)];
lag(lag<-0.01)=0.01;

time_doubling=lag+1./mu_log./log(2);
time_doubling=time_doubling';

PPU_time_init=pos.time_init(idx);
%%
%NaN
%%
PPU_mu_log=pos.mu_log(idx);
%%
%NaN
%%
PVE_time_init=pos.time_init(idxv);
%%
%0.00596388513917560	0.00368964469167120	0.00240445127100477	0.00133999988256193	0.00169256351776220	0.00231790714631464
%%
PVE_mu_log=pos.mu_log(idxv);
%%
%0.293637914161384	0.298735564325500	0.303734245349159	0.306992229767030	0.322850998098345	0.301350309535918
%%
PPU_PVE_time_init=pos.time_init(idxm);
%%
%0.00472445918175825	0.00214662422700725	-0.000617203924577885	5.20532615003903	0.00168875543547023	0.00325022916547946
%%
PPU_td=time_doubling(idx);
%% in h
%NaN
%%
PVE_td=time_doubling(idxv);
%%
PVE_td=[4.91914086710090	4.83302773888997	4.75226411635588	4.70079132470532	4.47030207498503	4.78975297934096];
%%
PPU_PVE_td=time_doubling(idxm);
%%
PVE_PPU_td=[5.62472032702486	5.25633390579302	5.43269615504123	7.55997731880380	5.06360909273506	5.46207015379743];


%% making boxplots of mu and time to first doubling.


PPU_mu=[0.538373940238686	0.529620058098032	0.539818761666151	0.559104085095022	0.548634884811794	0.575585170752410];
PPU_PVE_mu=[0.523927285745241	0.546356676294748	0.516962778105204	0.498883767241037	0.508906752753092	0.511529480375226]
PPU=[PPU_mu; PPU_PVE_mu];
PPU=PPU';
PVE_PPU_mu=[0.385949726375610	0.407045175844202	0.377631278652892	0.413069106237179	0.452998973378401	0.423862188401780];
PVE_mu=[0.324931625014460	0.357617334798899	0.354335990004726	0.340581904974859	0.343411943416151	0.349222433137798];
PVE=[PVE_mu; PVE_PPU_mu]';

[h p]= ttest2(PPU_mu, PPU_PVE_mu); %p =0.0089

[h p]= ttest2(PVE_mu, PVE_PPU_mu); %p=3.0606e-04

x=ones(6,1);
x2=2*x;

jitterAmount=0.3;
sz=15;

close all
FigH=figure;
posvector=[0.1, 0.1, 0.15, 0.3];

subplot('Position',posvector);
boxplot(PPU,'Widths',0.8);
hold on
jitterValues=2*(rand(size(x))-0.5)*jitterAmount;
scatter((x+jitterValues), PPU_mu,sz,'m','filled');
scatter((x2+jitterValues), PPU_PVE_mu, sz,'g','filled');
ylim([0 1]);
grid on
title('P.putida');
ylabel('Fluo signal growth rate (h-1)','FontSize',7);

posvector2=[0.4, 0.1, 0.15, 0.3];

subplot('Position',posvector2);
boxplot(PVE,'Widths',0.8);
hold on
jitterValues=2*(rand(size(x))-0.5)*jitterAmount;
scatter((x+jitterValues), PVE_mu,sz,'m','filled');
scatter((x2+jitterValues), PVE_PPU_mu, sz,'g','filled');
ylim([0 1]);
grid on
title('P.veronii')
ylabel('Fluo signal growth rate (h-1)','FontSize',7)

filename= strcat(Currentdir,'Figure2&S2&S3&S17/results_plots/Fig2_B.pdf')
saveas(FigH, filename, 'pdf');


