%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% extract droplet data file and separate into conditions, timepoints and replicates
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear

% Get path to the current directory of this script
resultPath = matlab.desktop.editor.getActiveFilename;
fprintf('%s\n', resultPath);
% Find all indices of the '/'
slashIndices = find(resultPath == '/');
% Find the index of the 3rd '/' from the end
thirdSlashFromEndIndex = slashIndices(end-2);
% Remove the part after the 3rd '/' from the end
Currentdir = resultPath(1:thirdSlashFromEndIndex);
fprintf('%s\n', Currentdir);

% path to main folder with images
Main = strcat(Currentdir,'Figure2&S2&S3&S17/results_plots/')

dataset=readtable(strcat(Main,'droplet_results.csv')); %as a table


%%filter on experiments
timepoints=[];
timep=[];
timepoints=table2cell(dataset(:,1)); %to be able to filter on time point T0, T24, T48
timepoint=unique(timepoints);

for j=1:length(timepoint)

    time=find(matches(string(timepoints),timepoint{j})); %
    exp_time=dataset(time,:);

    conditions=table2cell(exp_time(:,2)); %to be able to filter on conditions (C21, Ppu, Pve, PpuPve)
    condition=unique(conditions);

    for k=1:length(condition)

        aa=[];
        aa=find(matches(string(conditions),condition{k}));

        exp_aa=exp_time(aa,:);

        replicates=table2cell(exp_aa(:,3));
        replicate=unique(replicates);

        for z=1:length(replicate)

            ab=[]; ppm=[]; pvm=[]; pvpp=[]; empty=[];
            ab=find(matches(string(replicates),replicate{z}));

            exp_ab=exp_aa(ab,:);
            ppm=find(table2array(exp_ab(:,8))==0 & table2array(exp_ab(:,11))>0); %Fluo2Sum is Ppu
            pvm=find(table2array(exp_ab(:,11))==0 & table2array(exp_ab(:,8))>0); %Fluo1Sum is PVE
            pvpp=find(table2array(exp_ab(:,8))>0 & table2array(exp_ab(:,11))>0);
            empty=find(table2array(exp_ab(:,8))==0 & table2array(exp_ab(:,11))==0);

            timep(j).cond(k).rep(z).Ppu_Mono=exp_ab(ppm,:);
            timep(j).cond(k).rep(z).Pve_Mono=exp_ab(pvm,:);
            timep(j).cond(k).rep(z).Pve_Ppu=exp_ab(pvpp,:);
            timep(j).cond(k).rep(z).Empty=exp_ab(empty,:);

        end %end loop replicate

        clearvars ab exp_ab

        timep(j).cond(k).name=condition{k};
    end %end loop condition

    clearvars aa exp_aa
    timep(j).time=timepoint{j};
end %end loop time points


%% make a plot for saving

close all

%%median values at T24

for i=1:3
    med_Ppu_mono(i)=median(table2array(timep(2).cond(2).rep(i).Ppu_Mono(:,11)));
    med_Pve_mono(i)=median(table2array(timep(2).cond(3).rep(i).Pve_Mono(:,8)));
    med_Ppu_solo(i)=median(table2array(timep(2).cond(4).rep(i).Ppu_Mono(:,11)));
    med_Pve_solo(i)=median(table2array(timep(2).cond(4).rep(i).Pve_Mono(:,8)));
    med_Ppu_mix(i)=median(table2array(timep(2).cond(4).rep(i).Pve_Ppu(:,11)));
    med_Pve_mix(i)=median(table2array(timep(2).cond(4).rep(i).Pve_Ppu(:,8)));
end

results=vertcat(med_Ppu_mono, med_Ppu_solo, med_Ppu_mix, med_Pve_mono, med_Pve_solo, med_Pve_mix);
results(:,4)=mean(results(:,1:3),2); %mean of the replicates
results(1:3,5)=1-results(1:3,4)./results(2,4); %difference to mean of solo droplets
results(4:6,5)=1-results(4:6,4)./results(5,4);
results(:,6)=nan;
[h1,p1]=ttest(results(2,1:3),results(3,1:3));
results(3,6)=p1;
[h2,p2]=ttest(results(5,1:3),results(6,1:3));
results(6,6)=p2;

rows={'med_Ppu_mono','med_Ppu_solo','med_Ppu_mix','med_Pve_mono','med_Pve_solo','med_Pve_mix'}
cols={'REP1','REP2','REP3','Mean','difference','ttest'};
tab=array2table(results,'VariableNames',cols,'RowNames',rows);
writetable(tab,strcat(Main,'median-values.csv'),'WriteRowNames',true);

%%scatter plots of log10 median-nrmz data at T0 and T24

%%plot scatter coculture data

close all


FigH=figure;
subplot('Position',[0.1, 0.3, 0.3, 0.4]);

%%for T0

for i=1:3
    scatter(log10(timep(1).cond(4).rep(i).Pve_Ppu.Fluo2Sum),log10(timep(1).cond(4).rep(i).Pve_Ppu.Fluo1Sum),'.');
    hold on
end
xlabel('PPU log10 nrmz productivity in mix (Fluo2Sum))');
ylabel('PVE log10 nrmz productivity in mix (Fluo1Sum))');

grid on
xlim([-3 1]);
ylim([-3 1]);
legend
title('T0');

hold on

subplot('Position',[0.6, 0.3, 0.3, 0.4]);

for i=1:3
    scatter(log10(timep(2).cond(4).rep(i).Pve_Ppu.Fluo2Sum),log10(timep(2).cond(4).rep(i).Pve_Ppu.Fluo1Sum),'.');
    hold on
end
xlabel('PPU log10 nrmz productivity in mix (Fluo2Sum))');
ylabel('PVE log10 nrmz productivity in mix (Fluo1Sum))');

grid on
xlim([-3 1]);
ylim([-3 1]);
title('T24');


saveas(FigH, strcat(Main, 'FigS4_A.pdf'),'pdf');

%%count droplets

%T24

total_droplets_Ppu_solo=size(vertcat(timep(2).cond(4).rep(:).Ppu_Mono),1);
total_droplets_Pve_solo=size(vertcat(timep(2).cond(4).rep(:).Pve_Mono),1);
total_droplets_mix=size(vertcat(timep(2).cond(4).rep(:).Pve_Ppu),1);
total_droplets_empty=size(vertcat(timep(2).cond(4).rep(:).Empty),1);

sum_droplets=sum([total_droplets_Ppu_solo, total_droplets_Pve_solo, total_droplets_mix, total_droplets_empty]);

fraction_Ppu_solo=total_droplets_Ppu_solo/sum_droplets; %0.2590
fraction_Pve_solo=total_droplets_Pve_solo/sum_droplets; %0.2290
fraction_mix=total_droplets_mix/sum_droplets; %0.2623
fraction_empty=total_droplets_empty/sum_droplets; %0.2497

  
