


# Post processing
droplet_plate <- fc_table %>% 
  separate(Sample, c('Culture', 'Condition','BioRep', 'TechRep','FCcountingRep','DilutionFactor')) %>% 
  filter(Culture == 'droplet'|Culture == 'plate', preserve = TRUE) %>% 
  mutate(Medium = 'Su')  %>% #for Succinate
  mutate(NumberSpecies = case_when(Condition == "Ppu"|Condition == "Pve" ~ "mono" , Condition == "PpPv" ~ "mix" )) %>%
  mutate(VolumeAnalysed_µl = 20) # add a variable for the volume analysed in flow cytometry (µl) - 20µl for most of the wells
droplet_plate[2:102,'VolumeAnalysed_µl'] <- 40 # set volume to 40µl for some of the wells (check vol in lab book if necessary)
droplet_plate$DilutionFactor <- as.numeric(droplet_plate$DilutionFactor)

# transform wide data frame into a long data frame (around flow cytometry channels)
droplet_plate_long <- droplet_plate %>% 
  pivot_longer(cols=c(mCherryCount, GFPCount), names_to = "channel", values_to = "counts")
droplet_plate_long$channel[droplet_plate_long$channel == 'mCherryCount'] <- 'mCherry'
droplet_plate_long$channel[droplet_plate_long$channel == 'GFPCount'] <- 'GFP'

# Cell concentrations in fused droplets
droplet_cell_concentration <- droplet_plate_long %>% 
  filter(Culture == 'droplet')  %>% 
  mutate(CellConcentration = case_when(
    # PPU (gfp channel) - R1
    BioRep== 'R1' &Condition=='Ppu' &channel=='GFP'~ (counts/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80)*(1/ratio_non_emptyPP1),
    BioRep== 'R1' &Condition=='Pve' &channel=='GFP'~ (counts/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80),
    BioRep== 'R1' &Condition=='med' &channel=='GFP'~ (counts/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80),
    BioRep== 'R1' &Condition=='PpPv' &channel=='GFP'~ (counts/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80)*(1/ratio_non_emptyPPmix1),
    # R2
    BioRep== 'R2' &Condition=='Ppu' &channel=='GFP'~ (counts/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80)*(1/ratio_non_emptyPP2),
    BioRep== 'R2' &Condition=='Pve' &channel=='GFP'~ (counts/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80),
    BioRep== 'R2' &Condition=='med' &channel=='GFP'~ (counts/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80),
    BioRep== 'R2' &Condition=='PpPv' &channel=='GFP'~ (counts/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80)*(1/ratio_non_emptyPPmix2),
    #R3
    BioRep== 'R3' &Condition=='Ppu' &channel=='GFP'~ (counts/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80)*(1/ratio_non_emptyPP3),
    BioRep== 'R3' &Condition=='Pve' &channel=='GFP'~ (counts/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80),
    BioRep== 'R3' &Condition=='med' &channel=='GFP'~ (counts/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80),
    BioRep== 'R3' &Condition=='PpPv' &channel=='GFP'~ (counts/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80)*(1/ratio_non_emptyPPmix3),
    
    
    #250 = vol PBS in tube 
    #80 = initial vol droplets
    
    # PVE (mCherry channel) - R1
    BioRep== 'R1' &Condition=='Ppu' &channel=='mCherry'~ (counts/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80),
    BioRep== 'R1' &Condition=='med' &channel=='mCherry'~ (counts/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80),
    BioRep== 'R1' &Condition=='Pve' &channel=='mCherry'~ (counts/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80)*(1/ratio_non_emptyPV1),
    BioRep== 'R1' &Condition=='PpPv' &channel=='mCherry'~ (counts/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80)*(1/ratio_non_emptyPVmix1),
    # R2
    BioRep== 'R2' &Condition=='Ppu' &channel=='mCherry'~ (counts/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80),
    BioRep== 'R2' &Condition=='med' &channel=='mCherry'~ (counts/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80),
    BioRep== 'R2' &Condition=='Pve' &channel=='mCherry'~ (counts/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80)*(1/ratio_non_emptyPV2),
    BioRep== 'R2' &Condition=='PpPv' &channel=='mCherry'~ (counts/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80)*(1/ratio_non_emptyPVmix2),
    # R3
    BioRep== 'R3' &Condition=='Ppu' &channel=='mCherry'~ (counts/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80),
    BioRep== 'R3' &Condition=='med' &channel=='mCherry'~ (counts/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80),
    BioRep== 'R3' &Condition=='Pve' &channel=='mCherry'~ (counts/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80)*(1/ratio_non_emptyPV3),
    BioRep== 'R3' &Condition=='PpPv' &channel=='mCherry'~ (counts/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80)*(1/ratio_non_emptyPVmix3)
  ))
# in previous lines: adjust the concentration of Pve and Ppu based on the proportion of non empty droplets measured from droplets images of all replicates


### Calculate and subtract average noise signal detected in empty droplets controls 
droplet_cell_conc_filt <- droplet_cell_concentration
# remove mCherry events (PVE) noise
droplet_cell_conc_filt$CellConcentration[droplet_cell_conc_filt$channel == 'mCherry'] <- droplet_cell_conc_filt$CellConcentration[droplet_cell_conc_filt$channel == 'mCherry'] - mean(droplet_cell_conc_filt$CellConcentration[droplet_cell_conc_filt$Condition == 'med' & droplet_cell_conc_filt$channel =='mCherry']) 
# remove GFP events (PPU) noise
droplet_cell_conc_filt$CellConcentration[droplet_cell_conc_filt$channel == 'GFP'] <- droplet_cell_conc_filt$CellConcentration[droplet_cell_conc_filt$channel == 'GFP'] - mean(droplet_cell_conc_filt$CellConcentration[droplet_cell_conc_filt$Condition == 'med' & droplet_cell_conc_filt$channel == 'GFP']) 
# set negative values to 0
droplet_cell_conc_filt$CellConcentration[droplet_cell_conc_filt$CellConcentration < 0] <- 0


### same for plate samples
plate_cell_concentration <- droplet_plate_long %>% 
  filter(Culture == 'plate') %>% 
  mutate(CellConcentration = case_when(
    # PPU (GFP channel)
    channel=='GFP' ~ (counts/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor), 
    # PVE (mCherry channel)
    channel=='mCherry' ~ (counts/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)))

### Calculate and subtract average noise signal detected in empty droplets controls 
plate_cell_conc_filt <- plate_cell_concentration
# remove mCherry events (PV) noise
plate_cell_conc_filt$CellConcentration[plate_cell_conc_filt$channel == 'mCherry'] <- plate_cell_conc_filt$CellConcentration[plate_cell_conc_filt$channel == 'mCherry'] - mean(plate_cell_conc_filt$CellConcentration[plate_cell_conc_filt$Condition == 'med' & plate_cell_conc_filt$channel == 'mCherry'])
# remove GFP events (PP) noise
plate_cell_conc_filt$CellConcentration[plate_cell_conc_filt$channel == 'GFP'] <- plate_cell_conc_filt$CellConcentration[plate_cell_conc_filt$channel == 'GFP'] - mean(plate_cell_conc_filt$CellConcentration[plate_cell_conc_filt$Condition == 'med' & plate_cell_conc_filt$channel == 'GFP']) 
# set negative values to 0
plate_cell_conc_filt$CellConcentration[plate_cell_conc_filt$CellConcentration < 0] <- 0


# Concatenate droplets and plates cell concentration tables
cell_conc <- rbind(plate_cell_conc_filt, droplet_cell_conc_filt)
